@@ -11,6 +11,8 @@ val is_error : _ t -> bool
 
 val ok_exn : ('a, exn) t -> 'a
 
+val try_with : (unit -> 'a) -> ('a, exn) t
+
 module O : sig
   val ( >>| ) : ('a, 'error) t -> ('a -> 'b) -> ('b, 'error) t
   val ( >>= ) : ('a, 'error) t -> ('a -> ('b, 'error) t) -> ('b, 'error) t
@@ -21,6 +23,8 @@ val bind : ('a, 'error) t -> f:('a -> ('b, 'error) t) -> ('b, 'error) t
 
 val map_error : ('a, 'error1) t -> f:('error1 -> 'error2) -> ('a, 'error2) t
 
+val to_option : ('a, 'error) t -> 'a option
+
 (** Produce [Error <message>] *)
 val errorf : ('a, unit, string, (_, string) t) format4 -> 'a
 
